Frida Definitions Generator
===========================

Generate TypeScript definitions for a given APK file or unpacked apk directory.

NOTICE: you will need to install the nightly version of LIEF until they release
a version with the Dalvik fields fix. The installation command will look
something like this:

    $ python3 -m pip install --extra-index-url https://lief-project.github.io/packages frida-definitions-generator
